@@ -1,6 +1,6 @@
 package Bundle::Bugzilla;
 
-$VERSION = '0.07';
+$VERSION = '0.08';
 
 1;
 
@@ -28,6 +28,8 @@ Template 2.07
 
 Text::Wrap
 
+File::Spec 0.82
+
 =head1 DESCRIPTION
 
 This bundle installs the prerequisites for Bugzilla.
@@ -62,6 +64,9 @@ For templates in the bugzilla code. 2.07 is now required by Bugzilla.
 =item Text::Wrap
 Used to wrap text in comment fields
 
+=item File::Spec
+Used to get details on files
+
 =head1 AUTHOR
 
 Zach Lipton, <zach@zachlipton.com>
